#include <bastard.h>
#include <bdb.h>
#include <extension.h>


/* OUPUT ASM: Use ASM extension to create .asm file */
int plugin_main( FILE *f )
{
	if (!f)
		return (sys_set_lasterr(9010));
	return (ext_gen_asm_file(f));
}
